@@ -2,11 +2,9 @@
 from __future__ import print_function
 from distutils.spawn import find_executable
 from functools import lru_cache, wraps
-from tempfile import _TemporaryFileWrapper as TemporaryFileWrapperBase
 
 cache = lambda function: lru_cache(maxsize=128, typed=True)(function)
 
-import abc
 import clu.abstract
 import collections
 import collections.abc
@@ -15,16 +13,16 @@ import os
 import re
 import shutil
 import sys
-import weakref
 import zipfile
 
-from clu.constants.consts import λ, ENCODING, PATH, SCRIPT_PATH
+from clu.constants.consts import ENCODING, PATH, SCRIPT_PATH
 from clu.constants.exceptions import ExecutionError, FilesystemError
 from clu.dicts import OrderedItemsView, OrderedKeysView, OrderedValuesView
-from clu.predicates import attr, allattrs, isexpandable, anyof, uniquify
-from clu.repr import stringify
+from clu.predicates import attr, allattrs, isexpandable, anyof
+from clu.repr import stringify, strfields
 from clu.sanitizer import utf8_encode
 from clu.typology import isnotpath, isvalidpath
+from clu.fs.abc import TypeLocker, TemporaryFileWrapper
 from clu.fs.misc import differentfile, filesize, gethomedir, masked_permissions
 from clu.fs.misc import re_matcher, re_searcher, suffix_searcher, re_excluder
 from clu.fs.misc import swapext, u8str, extension
@@ -267,95 +265,6 @@ def modeflags(mode, delete=True):
     
     return flags
 
-@export
-class TypeLocker(abc.ABCMeta):
-    
-    """ clu.fs.filesystem.TypeLocker is a metaclass that does two
-        things with the types for whom it is designated as meta:
-        
-        1) It keeps an index of those types in a dictionary member of
-           the `TypeLocker` metaclass itself; and
-        
-        2) During class creation – the call to `TypeLocker.__new__(…)` –
-           it installs a class method called “directory(…)” that will,
-           when invoked, always return a new Directory instance that has
-           been initialized with the one provided argument “pth” (if one
-           was passed).
-        
-        … The point of this is to allow any of the classes throughout the
-        clu.fs.filesystem module regardless of where they are defined
-        or from whom they inherit, to make use of cheaply-constructed
-        Directory instances wherever convenient.
-        
-        Because the “directory(…)” method installed by TypeLocker performs
-        a lazy-lookup of the Directory class, using its own type index dict,
-        the order of definition does not matter i.e. the TemporaryName class
-        (q.v. definition immediately sub.) can use Directories despite its
-        definition occuring before Directory – in fact TemporaryName itself
-        is utilized within at least one Directory method – sans any issues.
-    """
-    
-    # The metaclass-internal dictionary of descendant type weakrefs:
-    types = weakref.WeakValueDictionary()
-    
-    def __new__(metacls, name, bases, attributes, **kwargs):
-        """ All classes are initialized with a “directory(…)”
-            static method, lazily returning an instance of the
-            clu.fs.filesystem.Directory(…) class.
-            
-            A read-only descriptor shadows the “types” attribute,
-            to block access to the metaclass type-registry dict
-            from generated subtypes, as well.
-        """
-        # Fill in the “types” attribute to prevent the metaclass’
-        # registry dict from leaking into subtypes:
-        attributes['types']         = clu.abstract.ValueDescriptor(tuple())
-        
-        # Always replace the “directory” method anew:
-        directory = lambda pth=None: metacls.types['Directory'](pth=pth)
-        
-        directory.__name__          = 'directory'
-        directory.__qualname__      = f'{name}.directory'
-        directory.__lambda_name__   = λ
-        attributes['directory']     = staticmethod(directory)
-        
-        # Call up (using a vanilla attributes dict):
-        cls = super(TypeLocker, metacls).__new__(metacls, name,
-                                                          bases,
-                                                          attributes,
-                                                        **kwargs)
-        
-        # Register with clu.fs.TypeLocker and os.PathLike:
-        metacls.types[name] = cls
-        os.PathLike.register(cls)
-        
-        # Return the new type
-        return cls
-
-class TemporaryFileWrapper(TemporaryFileWrapperBase,
-                           collections.abc.Iterable,
-                           contextlib.AbstractContextManager,
-                           os.PathLike,
-                           metaclass=TypeLocker):
-    
-    """ Local subclass of `tempfile._TemporaryFileWrapper`.
-        
-        We also inherit from both `contextlib.AbstractContextManager`
-        and the `os.PathLike` abstract bases -- the latter requires
-        that we implement an __fspath__(…) method (q.v. implementation,
-        sub.) -- and additionally, `filesystem.TypeLocker` is named as
-        the metaclass (q.v. metaclass __new__(…) implementation supra.)
-        to cache its type and register it as an os.PathLike subclass.
-        
-        … Basically a better deal than the original ancestor, like
-        all-around. Plus it does not have a name prefixed with an
-        underscore, which if it’s not your implementation dogg that
-        can be a bit lexically irritating.
-    """
-    
-    def __fspath__(self):
-        return self.name
-
 @cache
 def TemporaryNamedFile(temppath, mode='wb',
                                  delete=True,
@@ -382,7 +291,7 @@ def TemporaryNamedFile(temppath, mode='wb',
         
         Returns
         -------
-            A ``clu.fs.filesystem.TemporaryFileWrapper`` object,
+            A ``clu.fs.abc.TemporaryFileWrapper`` object,
             initialized and ready to be used, as per its counterpart(s),
             ``tempfile.NamedTemporaryFile``, and
             `filesystem.NamedTemporaryFile`.
@@ -548,8 +457,8 @@ class TemporaryName(collections.abc.Hashable,
     
     @property
     def filehandle(self):
-        """ Access a TemporaryNamedFile instance, opened and ready to read and write,
-            for this TemporaryName instances’ temporary file path.
+        """ Access a “clu.fs.abc.TemporaryNamedFile” instance, opened and ready
+            to read and write, for this TemporaryName instances’ file path.
             
             While this is a normal property descriptor – each time it is accessed,
             its function is called anew – the underlying `TemporaryNamedFile` call
@@ -706,6 +615,7 @@ class Directory(collections.abc.Hashable,
                 collections.abc.Mapping,
                 collections.abc.Sized,
                 clu.abstract.Cloneable,
+                clu.abstract.ReprWrapper,
                 contextlib.AbstractContextManager,
                 os.PathLike,
                 metaclass=TypeLocker):
@@ -960,6 +870,8 @@ class Directory(collections.abc.Hashable,
         """ Returns the path to a subpath of the instances’ target path --
             much like Directory.subpath(…) -- as an instance of Directory.
         """
+        if source is None and subdir == os.curdir:
+            return self
         path = self.subpath(subdir, source, requisite=False)
         if os.path.isfile(path):
             raise FilesystemError(f"file exists at subdirectory path: {path}")
@@ -1169,14 +1081,14 @@ class Directory(collections.abc.Hashable,
                                   source=None,
                                   excludes=('-', '+', 'pytest',
                                                       'obsolete',
-                                                      'scripts')):
+                                                      'repl.py')):
         """ List the importable file-based modules found within “subdir”,
             matching the “suffix” string, and not matching any of the
             “excludes” strings.
         """
         excluder = re_excluder(excludes)
         searcher = suffix_searcher(suffix)
-        dotpaths = []
+        dotpaths = set()
         target = self.subdirectory(subdir or os.curdir, source)
         # Use a call to “os.walk(…)” directly to allow modification of
         # the “dirs” list in-place:
@@ -1184,10 +1096,10 @@ class Directory(collections.abc.Hashable,
             dirs[:] = list(filter(excluder, dirs))
             filenames = filter(excluder,
                         filter(searcher, files))
-            dotpaths.extend(path_to_dotpath(os.path.join(root, filename),
+            dotpaths.update(path_to_dotpath(os.path.join(root, filename),
                                             relative_to=self.name)
                             for filename in filenames)
-        return sorted(uniquify(dotpaths))
+        return sorted(dotpaths)
     
     def suffix_histogram(self, subdir=None,
                                source=None,
@@ -1227,7 +1139,11 @@ class Directory(collections.abc.Hashable,
     
     def to_string(self):
         """ Stringify the Directory instance. """
-        return stringify(self, type(self).fields)
+        return strfields(self, type(self).fields)
+    
+    def inner_repr(self):
+        """ Stringify the Directory instance. """
+        return self.to_string()
     
     @wraps(dict.items)
     def items(self):
@@ -1244,9 +1160,6 @@ class Directory(collections.abc.Hashable,
     def clone(self, deep=False, memo=None):
         return self.directory(self.name)
     
-    def __repr__(self):
-        return self.to_string()
-    
     def __str__(self):
         if self.exists:
             return self.realpath()
