@@ -151,8 +151,8 @@ def format_environment(environment=None):
     for key, value in environment.items():
         jkey = f"{key}".ljust(most)
         begin = f"» {jkey} : "
-        if key.endswith('PATH') and ':' in value:
-            wvalue = pformat(value.split(':'))
+        if key.endswith('PATH') and os.pathsep in value:
+            wvalue = pformat(value.split(os.pathsep))
         else:
             wvalue = wrapper.fill(value)
         yield f"{begin}{wvalue}"
@@ -371,11 +371,16 @@ class InlineTester(collections.abc.Set,
             Optionally, a name may be specified.
         """
         from clu.exporting import determine_name
+        from clu.predicates import getpyattr
         
         # Stash the old name before assigning the new one:
         if name is not None:
             dname = determine_name(function)
-            function.__name__ = function.__qualname__ = name
+            qname = getpyattr(function, 'qualname')
+            if qname:
+                function.__qualname__ = qname.replace(
+                                        getpyattr(function, 'name'), name)
+            function.__name__ = name
             function.__function_name__ = dname
         
         # Wrap and return:
@@ -581,6 +586,7 @@ def stdpout():
     """
     # N.B. I fucking hate this Javaesque boilerplate-tastic shit
     import logging, pout
+    from clu.stdio import std
     
     # If we’ve been here before we don’t need to bother:
     if not getattr(pout, '__WTF_HAX__', False):
@@ -590,17 +596,17 @@ def stdpout():
             pout.stream.logger.handlers.pop()
             
             # Step two: set up a new logging StreamHandler:
-            loghandler = logging.StreamHandler(stream=sys.stdout)
+            loghandler = logging.StreamHandler(stream=std.OUT)
             loghandler.setFormatter(logging.Formatter('%(message)s'))
             pout.stream.logger.addHandler(loghandler)
             pout.stream.logger.propagate = False
             
             # Step three: instantiate a “pout.StderrStream” and root
-            # around with that shit to use `sys.stdout`:
+            # around with that shit to use `clu.stdio.std.OUT`:
             streamy = pout.StderrStream()
             streamy.logger = pout.stream.logger
             streamy.logger.setLevel(logging.DEBUG)
-            streamy.logger.handlers[0].setStream(sys.stdout)
+            streamy.logger.handlers[0].setStream(std.OUT)
             streamy.logger.handlers[0].set_name('stderr')
             streamy.logger.handlers[0].setLevel(logging.DEBUG)
             
@@ -697,17 +703,7 @@ def test():
         print()
     
     @inline
-    def test_three():
-        """ Busywork, mark III. """
-        pass
-    
-    @inline
-    def test_four():
-        """ Busywork, mark IV. """
-        pass
-    
-    @inline
-    def test_five_countfiles():
+    def test_three_countfiles():
         """ Testing “clu.testing.utils.countfiles(…)” """
         from clu.typology import isvalidpathlist
         from clu.fs.filesystem import TemporaryDirectory
@@ -740,8 +736,17 @@ def test():
         for envline in format_environment():
             print(envline)
     
+    @inline.diagnostic
+    def show_fixture_cache_stats():
+        """ Show the per-fixture-function cache stats """
+        total = len(inline.fixtures)
+        for idx, name in enumerate(inline.fixtures):
+            if idx > 0:
+                print()
+            print(f"FUNCTION CACHE INFO: {name} ({idx+1} of {total})")
+            print(inline.fixtures[name].cache_info())
+    
     return inline.test(100)
-    # return inline.test(100, mode='json')
 
 if __name__ == '__main__':
     sys.exit(test())
\ No newline at end of file
