@@ -7,10 +7,9 @@ import collections.abc
 import contextlib
 import sys
 
-from clu.constants.consts import STRINGPAIR, WHITESPACE, pytuple, NoDefault
-from clu.constants.polyfills import ispyname
+from clu.constants.consts import STRINGPAIR, WHITESPACE, ENCODING, pytuple, NoDefault
 from clu.dicts import merge_fast_two, asdict
-from clu.predicates import ismergeable
+from clu.predicates import ispyname, ismergeable
 from clu.exporting import Exporter
 
 exporter = Exporter(path=__file__)
@@ -52,13 +51,14 @@ class NamespaceRepr(Repr):
         """ The internal method for “core” repr production
             of all namespace descendant types.
         """
-        if len(thing) == 0:
+        if len(thing.__dict__) == 0:
             return "{}"
-        elif len(thing) == 1:
-            key = tuple(thing)[0]
+        elif len(thing.__dict__) == 1:
+            key = tuple(thing.__dict__.keys())[0]
             item = STRINGPAIR.format(key, self.subrepr(thing.__dict__[key], level))
             return f"{{ {item} }}"
-        items = (STRINGPAIR.format(key, self.subrepr(thing.__dict__[key], level)) for key in thing)
+        items = (STRINGPAIR.format(key, self.subrepr(thing.__dict__[key], level)) \
+                                          for key in thing.__dict__.keys())
         ts = "    " * (int(self.maxlevel - level) + 1)
         ls = "    " * (int(self.maxlevel - level) + 0)
         total = (f",\n{ts}").join(items)
@@ -110,7 +110,8 @@ nsshortrepr = reprizer.shortrepr
 
 @export
 class BaseNamespace(collections.abc.Set,
-                    collections.abc.Collection,
+                    collections.abc.Mapping,
+                    clu.abstract.Cloneable,
                     metaclass=clu.abstract.Slotted):
     
     """ The abstract base for SimpleNamespace and Namespace. """
@@ -140,6 +141,15 @@ class BaseNamespace(collections.abc.Set,
     def __contains__(self, key):
         return key in self.__dict__
     
+    def __getitem__(self, key):
+        try:
+            return self.__dict__.__getitem__(key)
+        except KeyError:
+            return self.__missing__(key)
+    
+    def __missing__(self, key):
+        raise KeyError(key)
+    
     def __eq__(self, other):
         return self.__dict__ == asdict(other)
     
@@ -153,8 +163,18 @@ class BaseNamespace(collections.abc.Set,
     def __repr__(self):
         return reprizer.fullrepr(self)
     
+    def __str__(self):
+        return reprizer.fullrepr(self, short=True)
+    
+    def __bytes__(self):
+        return bytes(str(self), encoding=ENCODING)
+    
     def __bool__(self):
         return bool(self.__dict__)
+    
+    def clone(self, deep=False, memo=None):
+        # Only shallow clone for the moment:
+        return type(self)(self.__dict__.copy())
 
 @export
 class SimpleNamespace(BaseNamespace,
@@ -224,21 +244,12 @@ class Namespace(BaseNamespace,
                        exc_tb=None):
         return exc_type is None
     
-    def __getitem__(self, key):
-        try:
-            return self.__dict__.__getitem__(key)
-        except KeyError:
-            return self.__missing__(key)
-    
     def __setitem__(self, key, value):
         self.__dict__.__setitem__(key, value)
     
     def __delitem__(self, key):
         self.__dict__.__delitem__(key)
     
-    def __missing__(self, key):
-        raise KeyError(key)
-    
     def __add__(self, operand):
         # On add, old values are not overwritten
         if not ismergeable(operand):
@@ -352,6 +363,22 @@ def test():
         except NamespaceKeyError as exc:
             assert bool(exc)
     
+    @inline
+    def test_four():
+        """ Compatibility with standard-library “types.SimpleNamespace” """
+        import types
+        
+        stdn = types.SimpleNamespace(**flat_dict())
+        sn = SimpleNamespace(flat_dict())
+        
+        assert stdn.__dict__ == sn.__dict__
+        assert nsrepr(stdn) == nsrepr(sn)
+        assert nsshortrepr(stdn) == nsshortrepr(sn)
+        
+        print(repr(stdn))
+        print()
+        print(repr(sn))
+    
     return inline.test(100)
 
 if __name__ == '__main__':
